@@ -171,7 +171,7 @@ button.onclick = function() {
     var checkinput = 1;
     if ((values["betragop"]=="" || isNaN(parseInt(values["betragop"]))) && values["betragka"]==0 && values["betragwn"]==0 && values["betragso"]==0) {
         checkinput = 0;
-        betragges = "Geben Sie eine Betrag ein oder wählen Sie 'keine Angaben' bzw. 'weiß nicht' !";
+        betragges = "Geben Sie einen Betrag ein oder wählen Sie 'keine Angaben' bzw. 'weiß nicht' !";
     }
     if ((values["betragka"]==1 || values["betragwn"]==1) && ((values["oberka"]==1 && values["unterka"]==1))) {
         checkinput = 0;
@@ -195,7 +195,7 @@ button.onclick = function() {
     if (((values["betragka"]==1 || values["betragwn"]==1) && (values["bereichka"]==1 || values["bereichwn"]==1)) &&
         (values["kategorie"] == ""))  {
         checkinput = 0;
-        betragges = "Wählen Sie eien Kategorie aus der Liste oder 'keine Angaben' bzw. 'weiß nicht' !";
+        betragges = "Wählen Sie eine Kategorie aus der Liste oder 'keine Angaben' bzw. 'weiß nicht' !";
     }
     console.log("Betrag: "+values["betragop"]+"parseInt: "+parseInt(values["betragop"])+" -Min: "+min+"-Max: "+max+"-BetragKA: "+values["betragka"]+"-BetragWN: "+values["betragwn"]+"-Sonder: "+values["betragso"]);
     if ((parseInt(values["betragop"])<min || parseInt(values["betragop"])>max) && values["betragka"]==0 && values["betragwn"]==0) {
