@@ -16,7 +16,6 @@ function getProjConfig() {
 		"HFCS12_Abschluss" => "hfcs2020_config",
 		//"HFCS01_Screener" => "hfcs2020_config",
 		"HFCS00_Paradaten" => "hfcs2020_config",
-		"HFCS00_Kontakte" => "hfcs2020_config",
 	);
 	//echo $_SESSION['projname'];
 	$config = $projConfig[$_SESSION['projname']];
@@ -29,10 +28,10 @@ function get_quest_text () {
 }
 
 function isProxy() {
-	if (reset(getVarFromHFCS("HFCS01_Screener","AHL0130"))==2) {
-		return true;
-	} else {
+	if (reset(getVarFromHFCS("HFCS01_Screener","AHL0130"))==1) {
 		return false;
+	} else {
+		return true;
 	}
 }
 function anzPers() {
@@ -249,17 +248,6 @@ function getBez($persnr) {
 	//echo "alterscode ".reset(getVar("RA030x".$persnr.""))."<br>";
 	return $age_array[reset(getVarFromHFCS("HFCS01_Screener","RA010x".$persnr.""))];
 }
-/**
- * Wandelt offenes Eingabefeld (text) in Euroloop Formular um.
- * Zusätzlicher Eintrag im js notwendig
- *
- * @param string $interval zu verwendetet Kategorie A-C lt Fragebogen
- * @param int $min Betragsuntergrenze lt. Fragebogen bzw. Hard-Konsitenzcheck
- * @param int $max Betragsobergrenze lt. Fragebogen bzw. Hard-Konsitenzcheck
- * @param string $sonder Text für Sonderantwort, bei NULL (Standard) wird keine Sonderantwort angezeigt
- * @param string $preWaehrung Auswahl der Vorausgewählten Währung, Standard = 1 Euro, 0 für keine Vorauswahl
- *
-*/
 function euroloop($interval = "A",$min = 0,$max = 999999999,$sonder = NULL,$preWaehrung = 1) {
 
 	$intervalA = array(
@@ -635,18 +623,9 @@ function checkRedButton() {
 	return false;
 }
 function beautyEuro($value) {
-	// echo "Value1: ".$value."<br>";
-	$korrminus = 0;
-	if ($value<0) {
-		$korrminus = 1;
-		$value = $value*-1;
-	}
-	// echo "Value2: ".$value."<br>";
 	if (strlen($value)>6 ) $euroBeauty .= substr($value,0,-6).".";
 	if (strlen($value)>3 ) $euroBeauty .= substr(substr($value,-6),0,-3).".";
 	if (strlen($value)>=1 ) $euroBeauty .= substr($value,-3,3);
-	if ($korrminus == 1) $euroBeauty = "-".$euroBeauty;
-	// echo "Value3: ".$euroBeauty."<br>";
 	return $euroBeauty;
 }
 function checkRedButtonLoop($loopname) {
@@ -802,7 +781,7 @@ function getAnswerText($label,$item=NULL) {
 	return $answerText;
 }
 
-function linkBack($HFCS_ARRAY,$fbPart=NULL) {
+function linkBack($HFCS_ARRAY) {
 	$questtxt ="";
 	$newUrl = 0;
 	$urlPath = $GLOBALS["paths"]["warpit_www"];
@@ -819,7 +798,7 @@ function linkBack($HFCS_ARRAY,$fbPart=NULL) {
 	// var_dump($_SESSION);
 	foreach ($HFCS_ARRAY as $fbTeil=>$value) {
 		// echo $fbTeil;
-		if ($fbTeil == $aktFrabo || $fbPart=="HFCS00_Base") break;
+		if ($fbTeil == $aktFrabo) break;
 		$linkConfig = $links[$fbTeil];
 		// dumpvar($linkConfig);
 		if ($fbTeil == "HFCS08_Erwerb") {
